# -*- coding: utf-8 -*-
"""The 'FileSysObjects' module provides basic file inheritance by directory hierarchies.  

This modules manages the file system based structure semantics for 
the automation of drop-in configurations. Therefore functions and classes
are provided for the modification of the search path and the location of
files and directories. Two examples are:

* The search for files and/or relative paths from a given 
    directory on upwards.
* The extension of search paths with any sub-directory portion 
    from a given directory on upwards.  

These two features already provide for basic inheritance 
features for files in directory hierarchies.

"""
from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.3'
__uuid__='9de52399-7752-4633-9fdc-66c87a9200b8'

__docformat__ = "restructuredtext en"

import os,sys
version = '{0}.{1}'.format(*sys.version_info[:2])
if version < '2.7': # pragma: no cover
    raise Exception("Requires Python-2.7.* or higher")

import inspect 

from filesysobjects.PySourceInfo import getSourceFilePathName

class FileSysObjectsException(Exception):
    pass

def setUpperTreeSearchPath(start=None,top=None,plist=None):
    """Extends the search by sys.path for each subdir from 'start' on upward to 'top'.
    
    Prepends a set of search paths into sys.path. The set of search 
    paths contains of each directory beginning with provided start 
    position. This enables a "polymorphic inheritance view" onto the 
    file system structure.
    
    The typical application is the grouping of imported modules/classes
    for test cases by file-inheritance from upper tree. This provides 
    the hierarchical configuration and specialization of test cases 
    with pre-defined default components by multiple levels of 
    configuration files. 

    Args:
        start: Start directory.

            default := caller-file-position.
        
        top: End directory.
        
            default := start

        plist: List to for the storage.
        
            default := sys.path

    Returns:
        When successful returns 'True', else returns either 'False', or
        raises an exception.

    Raises:
        passed through exceptions:
    """
    if plist == None:
        plist = sys.path

    # 0. prep start dir
    if start == '':
        raise FileSysObjectsException("Empty top:''")
    elif start == None:
        start = getSourceFilePathName(2) # caller file
    s = os.path.abspath(start)
    if os.path.isfile(start):
        s = os.path.dirname(s) # we need dir
    if not os.path.exists(s):
        raise FileSysObjectsException("Missing start:"+str(s)) 

    # 1. prep top dir
    if top == '':
        raise FileSysObjectsException("Empty top:''")
    elif top == None:
        plist.insert(0,s)
        return True
    else:
        a = s.split(top)
        
        if len(a) == 1: # top is not in start
            raise FileSysObjectsException("Missing top:"+str(top))

        elif a == ['','']: # handles top==start
            plist.insert(0,top)
            return True
        
        elif len(a)>2: # multiple occurances, for not not supported
            raise FileSysObjectsException("Ambigious top:"+str(top)) # top more than once in start
        
        else: # exactly 2 - one only
            
            if a[0] == '': # top was prefix
                a = a[1]
                curp = top
                plist.insert(0,curp)
                a = a.split(os.sep)
            
                for p in a:
                    curp = os.path.join(curp,p)
                    if p != '':
                        curp += os.sep
                    plist.insert(0,curp)

            else: # actual top
                curp = os.path.normpath(a[0]+os.sep+top)
                plist.insert(0,curp)

                a = a[1].split(os.sep)
                            
                for p in a:
                    if not p:
                        continue
                    curp = os.path.join(curp,p)
                    if p != '':
                        curp += os.sep
                    plist.insert(0,curp)

    return True

def findRelPathInUpperTree(object,plist=None):
    """Searches the upper tree path list for matching objects in side-branches.
    
    Args:
        object: A relative path to a directory or file.
                Some examples are 'myscript.sh', 'epyunit/myscript.sh', or
                'bin/epyunit'.

        plist: List with path entries to search each, first match wins.
        
            default := sys.path

    Returns:
        When successful returns the absolute pathname, else 'None'.

    Raises:
        passed through exceptions:
    """
    if plist == None:
        plist = sys.path
    for p in plist:
        if os.path.exists(p+os.sep+object):
            return os.path.normpath(os.path.abspath(p+os.sep+object))

    return None




"""Use-Cases 'FileSysObjects'

* setUpperTreeSearchPath - Create hierarchical search paths.

* findRelPathInUpperTree - Find the absolute realpath of a relative filepathname.

* getCallerName - Get the name of the caller. 

* getModuleFilePathName - Get the filepathname of a module. 

* getModulePathName - Get the pathname of a module. 

* getSourceFilePathName - Get the source filepathname of the caller. 

* getSourceFuncName - Get the function name of the caller. 

* getSourceLinenumber - Get the line number of the call. 

"""


# -*- coding: utf-8 -*-
"""PySourceInfo - runtime type information on Python source location: package, module, and caller.  

This modules provides for the location of Python execution 
by means of the package 'inspect' extended by additional sources
for a simple API.

The stack frame of inspect is in particular reduced to the common 
parameter 'spos', which is an abstraction of the 'stack-position'
representing the level of history within the caller level.
The value 'spos==0' is the function itself, whereas 'spos==1' is the 
first level caller. Consequently 'spos==2' is the caller of the caller,
etc.  

The categories of provided RTTI comprise:
 
* **packages** - Python packages.

* **modules** - Python modules - a.k.a. source files.

* **callers** - Python functions and class/object methods.


Where the following attributes are available:

* name(package, module, function)

* OID - dotted relative path to matching item of sys.path

* filename

* filepathname

* item of sys.path

* relative path to item of sys.path

* line number

Dependent on the call context, some of the attribute values may 
not be available.
E.g. when called from within the python/ipython shell, or 'main'.

The API is designed here as a collection of slim functions 
only in order to avoid any overhead for generic application.

"""
from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.3'
__uuid__='9de52399-7752-4633-9fdc-66c87a9200b8'

__docformat__ = "restructuredtext en"

import os,sys
version = '{0}.{1}'.format(*sys.version_info[:2])
if version < '2.7': # pragma: no cover
    raise Exception("Requires Python-2.7.* or higher")

import inspect 


class PySourceInfoException(Exception):
    pass

def getSourceFilePathName(spos=1):
    """Returns the pathname of caller source file.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the filepathname.

    Raises:
        passed through exceptions:
    """
    return inspect.stack()[spos][1]

def getSourceFuncName(spos=1):
    """Returns the name of caller function.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the filepathname.

    Raises:
        passed through exceptions:
    """
    return inspect.stack()[spos][3]

def getSourceLinenumber(spos=1):
    """Returns the line number of caller.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the filepathname.

    Raises:
        passed through exceptions:
    """
    return inspect.stack()[spos][2]

def getCallerName(spos=1):
    """Returns the name of the caller.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the filepathname.

    Raises:
        passed through exceptions:
    """
    return inspect.stack()[spos][0].f_globals['__name__']

def getCallerNameOID(spos=1):
    """Returns the name of the package containing the caller.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the package name.

    Raises:
        passed through exceptions:
    """
    _spos = spos
    _sf = inspect.stack()
    if len(_sf) < _spos:
        return None
    _pf = _sf[_spos][0]
    _coid = inspect.getmodule(_pf)
    if _coid:
        _coid = _coid.__name__
    if 'self' in _pf.f_locals:
        _coid += "." + str(_pf.f_locals['self'].__class__.__name__)
    if _pf.f_code.co_name != '<module>':
        _coid += "." + str(_pf.f_code.co_name)
    del _pf
    return _coid

def getCallerPackageName(spos=1):
    """Returns the name of the package containing the caller.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the package name when defined, else None.

    Raises:
        passed through exceptions:
    """
    _sf = inspect.stack()
    if len(_sf) < spos:
        return None
    module = inspect.getmodule(_sf[spos][0])
    if module:
        return module.__package__
    
def getCallerPackagePathName(spos=1):
    """Returns the pathname to the package directory of the caller.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the path name to the package.

    Raises:
        passed through exceptions:
    """
    _sf = inspect.stack()
    if len(_sf) < spos:
        return None
    module = inspect.getmodule(_sf[spos][0])
    if module:
        if module.__package__:
            #FIXME: zip-files
            return getCallerModulePathName(spos+1)

def getCallerPackagePythonPath(spos=1):
    """Returns the pathname to the package directory of the caller.

    Intentionally the same as 'getCallerPackagePathName'.
 
    Args:
        spos: Start position in the stack.

    Returns:
        Returns the path name to the package.

    Raises:
        passed through exceptions:
    """
    return os.path.dirname(getCallerPackagePathName(spos+1))

def getCallerPackageFilePathName(spos=1):
    """Returns the name of the package containing the caller.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the package name.

    Raises:
        passed through exceptions:
    """
    return os.path.dirname(getCallerModuleFilePathName(spos+1))

def getCallerModuleFilePathName(spos=1):
    """Returns the filepathname of the module.

    Args:
        spos: Start position in the stack.

    Returns:
        Returns the filepathname of the caller module.

    Raises:
        passed through exceptions:
    """
    
    _sf = inspect.stack()
    if len(_sf) < spos:
        return None
    module = inspect.getmodule(_sf[spos][0])
    if module:
        return module.__file__

def getCallerModuleName(spos=1):
    """Returns the name of the caller module.

    Args:
        spos: Module name.

    Returns:
        Returns the name of caller module.
        The dotted object path is relative to 
        the actual used sys.path item.  

    Raises:
        passed through exceptions:
    """
    _sf = inspect.stack()
    if len(_sf) < spos:
        return None
    module = inspect.getmodule(_sf[spos][0])
    if module:
        return module.__name__

def getCallerModulePythonPath(spos=1):
    """Returns the prefix item from sys.path used for the caller module.

    Args:
        spos: Module name.

    Returns:
        Returns the name of caller module.

    Raises:
        passed through exceptions:
    """
    _mn = getCallerModuleName(spos+1).split('.')[:-1]
    _mn = os.sep.join(_mn)
    _r = getCallerModulePathName(spos+1).split(_mn)[0]
    if _r[-1] != os.sep: # was rel for split
        _r += os.sep
    return _r    

def getCallerModulePathName(spos=1):
    """Returns the pathname of the module.

    Args:
        m: Module name.

    Returns:
        Returns the filepathname of module.

    Raises:
        passed through exceptions:
    """
    return os.path.dirname(getCallerModuleFilePathName(spos+1))+os.sep

def getPythonPathPrefixMatchFromSysPath(pname,plist=None):
    """Gets the first matching prefix from sys.path.
    
    Foreseen to be used for canonical base reference in unit tests.
    This enables in particular for casual tests where absolute pathnames
    are required.

    Args:
        pname: Pathname.

    Returns:
        Returns the first matching path prefix from sys.path.

    Raises:
        passed through exceptions:
    """
    if not plist:
        plist = sys.path
    for sp in plist:
        if pname.startswith(sp):
            if sp and sp[-1] == os.sep:
                return sp
            return sp+os.sep

def getPythonPathModuleRel(fpname,plist=None):
    """Returns the relative path name of the filepathname.

    Args:
        fpname: The filepathname.

    Returns:
        Returns the path prefix for fpname.

    Raises:
        passed through exceptions:
    """
    if not plist:
        plist = sys.path
    for _sp in plist:
        if fpname.startswith(_sp):
            _r = fpname.replace(_sp,"")
            if _r and _r[0] == os.sep:
                return _r[1:]
            return _r

def getPythonPathForPackage(pname,plist=None):
    """Returns the item from sys.path for package.

    ATTENTION: This version relies on the common
        naming convention of pathnames.

    Args:
        pname: The name of the package.

    Returns:
        Returns the path item.

    Raises:
        passed through exceptions:
    """
    if not plist:
        plist = sys.path    
    _pn = pname.replace('.',os.sep)
    for _sp in sys.path:
        _pp = _sp.split(pname)
        if len(_pp) > 1:
            return _pp[0]



"""Check the expansion of 'sys.path' by PATH components derived from splice of upper tree.
"""
from __future__ import absolute_import

import unittest
import os

from filesysobjects.FileSysObjects import setUpperTreeSearchPath


#
#######################
#
class CallUnits(unittest.TestCase):
    name=os.path.curdir+__file__

    output=True
    output=False

    #
    # Create by object
    #
    def testCase000(self):

        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        top = os.path.abspath(os.path.dirname(__file__))+os.sep  #@UnusedVariable
        start = top+A

        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.dirname(top+A)+os.sep,
            top,
        ]

        assert resx == res
        pass

    def testCase001(self):

        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        top = os.path.abspath(os.path.dirname(__file__))+os.sep
        start = top+B

        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.dirname(top+B)+os.sep,
            top,
        ]
        resx.insert(1,os.path.dirname(resx[0][:-1])+os.sep)

        assert resx == res
        pass

    def testCase002(self):

        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        top = os.path.abspath(os.path.dirname(__file__))+os.sep
        start = top+C

        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.dirname(top+C)+os.sep,
            top,
        ]
        resx.insert(1,os.path.dirname(resx[0][:-1])+os.sep)
        resx.insert(2,os.path.dirname(resx[1][:-1])+os.sep)

        assert resx == res
        pass

    def testCase003(self):

        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        top = os.path.abspath(os.path.dirname(__file__))+os.sep
        start = top+D

        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.dirname(top+D)+os.sep,
            top,
        ]
        resx.insert(1,os.path.dirname(resx[0][:-1])+os.sep)
        resx.insert(2,os.path.dirname(resx[1][:-1])+os.sep)
        resx.insert(3,os.path.dirname(resx[2][:-1])+os.sep)

        assert resx == res
        pass

if __name__ == '__main__':
    unittest.main()



"""Distribute 'filesysobjects', a generic unit test wrapper for commandline interfaces.

   Installs 'filesysobjects', adds/modifies the following helper features to standard
   'setuptools' options.

   Args:
      build_sphinx: Creates documentation for runtime system by Sphinx, html only.
         Calls 'callDocSphinx.sh'.
      build_epydoc: Creates documentation for runtime system by Epydoc, html only.
         Calls 'callDocEpydoc.sh'.

      test: Runs PyUnit tests by discovery.

      --no-install-required: Suppresses installation dependency checks, 
          requires appropriate PYTHONPATH.
      --offline: Sets online dependencies to offline, or ignores online
          dependencies.

      --exit: Exit 'setup.py'.

      --help-filesysobjects: Displays this help.

   Returns:
      Results for success in installed 'filesysobjects'.

   Raises:
      ffs.

"""
# priority is offline here - needs manual 'bootstrap', thus dropped ez_setup for now
# import ez_setup
# ez_setup.use_setuptools()

#import sys
#from polybori.plot import THEN

#
#*** common source header
#
__author__ = 'Arno-Can Uestuensoez'
__author_email__ = 'acue_sf2@sourceforge.net'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2015-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.4'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'


# some debug
if __debug__:
    __DEVELTEST__ = True

#
#***
#
import os,sys
from setuptools import setup #, find_packages
import fnmatch
import re


#
#*** ===>>> setup.py helper
#
def find_files(srcdir, *wildcards, **kw):
    """Assembles a list of package files for package_files.

        Args:
            srcdir: Source root.
            *wildcards: list of globs.
            **kw: Additional control of resolution:
                single_level: Flat only.
                subpath: Cut topmost path elemenr from listelements,
                    special for dictionaries.
                nopostfix: Drop filename postfix.
                packages: List packages only, else files.
                yield_folders:
        Returns:
            Results in an list.

        Raises:
            ffs.

    """
    def all_files(root, *patterns, **kw):
        ret=[]
        single_level = kw.get('single_level', False)
        subpath = kw.get('subpath', False)
        nopostfix = kw.get('nopostfix', True)
        packages = kw.get('packages', True)
        yield_folders = kw.get('yield_folders', True)

        for path, subdirs, files in os.walk(root):
            if yield_folders:
                files.extend(subdirs)
            files.sort( )

            if subpath:
                path=re.sub(r'^[^'+os.sep+']*'+os.sep, '',path)

            for name in files:
                if name in ('.gitignore', '.git', '.svn'):
                    continue

                for pattern in patterns:
                    if fnmatch.fnmatch(name, pattern):
                        if packages:
                            if not name == '__init__.py':
                                continue
                            ret.append(path)
                            continue
                        if nopostfix:
                            name=os.path.splitext(name)[0]

                        ret.append(os.path.join(path, name))

            if single_level:
                break
        return ret

    file_list = all_files(srcdir, *wildcards,**kw)
    return file_list

def usage():
    if __name__ == '__main__':
        import pydoc
        #FIXME: literally displayed '__main__'
        print pydoc.help(__name__)
    else:
        help(str(os.path.basename(sys.argv[0]).split('.')[0]))

#
#* shortcuts
#

exit_code = 0

# custom doc creation by sphinx-apidoc
if 'build_sphinx' in sys.argv:
    print "#---------------------------------------------------------"
    exit_code = os.system('./callDocSphinx.sh') # create apidoc
    print "#---------------------------------------------------------"
    print "Called/Finished callDocSphinx.sh => exit="+str(exit_code)
    sys.argv.remove('build_sphinx')

# custom doc creation by epydoc
if 'build_epydoc' in sys.argv:
    print "#---------------------------------------------------------"
    exit_code = os.system('./callDocEpydoc.sh') # create apidoc
    print "#---------------------------------------------------------"
    print "Called/Finished callDocEpydoc.sh => exit="+str(exit_code)
    sys.argv.remove('build_epydoc')

# call of complete test suite by 'discover'
if 'test' in sys.argv:
    print "#"
    exit_code = os.system('python -m unittest discover -s tests -p CallCase.py') # traverse tree
    print "#"
    print "Called/Finished PyUnit tests => exit="+str(exit_code)
    print "exit setup.py now: exit="+str(exit_code)
    sys.argv.remove('test')

# Intentional HACK: ignore (online) dependencies, mainly foreseen for developement
__no_install_requires = False
if '--no-install-requires' in sys.argv:
    __no_install_requires = True
    sys.argv.remove('--no-install-requires')

# Intentional HACK: offline only, mainly foreseen for developement
__offline = False
if '--offline' in sys.argv:
    __offline = True
    __no_install_requires = True
    sys.argv.remove('--offline')

# Execution failed - Error.
if exit_code != 0:
    sys.exit(exit_code)

# Help on addons.
if '--help-filesysobjects' in sys.argv:
    usage()
    sys.exit(0)

# Exit here.
if '--exit' in sys.argv:
    sys.exit(0)

# if filesysobjects-specials only
if len(sys.argv)==1:
    sys.exit(exit_code)

#
#*** <<<=== setup.py helper
#


#
#*** setup.py configuration
#
_name='pyfilesysobjects'

_description=("The 'pyfilesysobjects' package provides utilities for usage of the filesystem as a class tree" 
              "containing files as objects. "
              "In addition the package 'inspect' is encapsulated for simplified application on packages, modules, and sources."
              )

# def read(fname):
#     return open(os.path.join(os.path.dirname(__file__), fname)).read()
_README = os.path.join(os.path.dirname(__file__), 'README')
_long_description = open(_README).read() + 'nn'

_platforms='any'

_classifiers = [
    "Development Status :: 3 - Alpha",
    "Intended Audience :: Developers",
    "License :: Free To Use But Restricted",
    "License :: OSI Approved :: Artistic License",
    "Natural Language :: English",
    "Operating System :: Microsoft :: Windows :: Windows 7",
    "Operating System :: OS Independent",
    "Operating System :: POSIX :: BSD :: OpenBSD",
    "Operating System :: POSIX :: Linux",
    "Operating System :: POSIX",
    "Programming Language :: Python",
    "Programming Language :: Python :: 2",    
    "Programming Language :: Python :: 2.7",    
    "Programming Language :: Unix Shell",
    "Topic :: Software Development :: Libraries :: Python Modules",
    "Topic :: Utilities",
]

_keywords  = ' Filesystem Python Syntax Packages Modules Files Linenumbers Filenames Modulenames Packagenames'
_keywords += ' fileobjects Objects Classes Objecttrees Classtrees inspect'

_packages = ["filesysobjects"]
_scripts = []

_package_data = {
    'filesysobjects': ['README','ArtisticLicense20.html', 'licenses-amendments.txt',
            ],
}

#_download_url="https://github.com/ArnoCan/filesysobjects/"
_download_url="https://sourceforge.net/projects/pyfilesysobjects/files/"

_url='https://sourceforge.net/projects/pyfilesysobjects/'

_install_requires=[
    'inspect',
    're',
#    'termcolor'
]

_test_suite="tests.CallCase"

if __debug__:
    if __DEVELTEST__:
        print "#---------------------------------------------------------"
        print "packages="+str(_packages)
        print "#---------------------------------------------------------"
        print "package_data="+str(_package_data)
        print "#---------------------------------------------------------"



#
#*** ===>>> setup.py helper
#

# Intentional HACK: ignore (online) dependencies, mainly foreseen for developement
if __no_install_requires:
    print "#"
    print "# Changed to offline mode, ignore install dependencies completely."
    print "# Requires appropriate PYTHONPATH."
    print "# Ignored dependencies are:"
    print "#"
    for ir in _install_requires:
        print "#   "+str(ir)
    print "#"
    _install_requires=[]

#
#*** <<<=== setup.py helper
#


#
#*** do it now...
#
setup(name=_name,
      version=__version__,
      author=__author__,
      author_email=__author_email__,
      classifiers=_classifiers,
      description=_description,
      download_url=_download_url,
      install_requires=_install_requires,
      keywords=_keywords,
      license=__license__,
      long_description=_long_description,
      platforms=_platforms,
      url=_url,
      scripts=_scripts,
      packages=_packages,
      package_data=_package_data
)



"""Check search of a relative filepathname - side-branch - in upper tree.
"""
from __future__ import absolute_import
from __future__ import print_function

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os

# #
# # set search for the call of 'myscript.sh'
# from filesysobjects.FileSysObjects import setUpperTreeSearchPath
# setUpperTreeSearchPath(None,'UseCases')

from filesysobjects.FileSysObjects import findRelPathInUpperTree
from filesysobjects.PySourceInfo import getPythonPathModuleRel


#
#######################
#

class CallUnits(unittest.TestCase):
    name=os.path.curdir+__file__

    output=True
    output=False

    def testCase000(self):
        epy = findRelPathInUpperTree("test00")
        epy = getPythonPathModuleRel(epy,[os.path.abspath(os.path.dirname(__file__)+'../../../../..')])
        x = "UseCases/filesysobjects/FileSysObjects/test00"
        assert epy == x
        pass

    def testCase001(self):
        epy = findRelPathInUpperTree("test01")
        epy = getPythonPathModuleRel(epy,[os.path.abspath(os.path.dirname(__file__)+'../../../../..')])
        x = "UseCases/filesysobjects/test01"
        assert epy == x
        pass

    def testCase002(self):
        epy = findRelPathInUpperTree("test02")
        epy = getPythonPathModuleRel(epy,[os.path.abspath(os.path.dirname(__file__)+'../../../../..')])
        x = "UseCases/test02"
        assert epy == x
        pass
#
#######################
#

if __name__ == '__main__':
    unittest.main()

